pub struct DisjointSetStruct<NI: Idx>(/* private fields */);Expand description
A thread-safe Disjoint Set Struct implementation, that can be safely shared and accessed across threads.
The implementation is based on the Java implementation [1] which in turn is based on a C++ implementation and some input from a Rust implementation [3].
This implementation is tailored for the graph crate as
it needs to support the Idx trait.
Implementations