pub struct PageRankConfig {
pub max_iterations: usize,
pub tolerance: f64,
pub damping_factor: f32,
}Fields
max_iterations: usizeThe maximum number of page rank iterations.
tolerance: f64If the sum of page rank deltas per iteration is below the tolerance value, the computation stop.
damping_factor: f32Imagining a random surfer clicking links, the damping factor defines the probability if the surfer will continue at any step.
Implementations
Sourceimpl PageRankConfig
impl PageRankConfig
pub const DEFAULT_MAX_ITERATIONS: usize = 20
pub const DEFAULT_TOLERANCE: f64 = 1E-4
pub const DEFAULT_DAMPING_FACTOR: f32 = 0.85
pub fn new(max_iterations: usize, tolerance: f64, damping_factor: f32) -> Self