Re-exports
pub use crate::page_rank::*;pub use crate::sssp::*;pub use crate::triangle_count::*;pub use crate::utils::*;pub use crate::wcc::*;
Modules
Structs
- Atomic
- A generic atomic wrapper type which allows an object to be safely shared between threads.
- Binary
Input - Reads a graph that has been written via
crate::graph_ops::SerializeGraphOp. - DirectedAL
Graph - Directed
CsrGraph - Edge
List - Edge
List Input - Reads a graph from a file that contains an edge per line.
- Graph500
- Graph500
Input - Graph
Builder - A builder to create graphs in a type-safe way.
- Input
Path - Target
- Represents the target of an edge and its associated value.
- UndirectedAL
Graph - Undirected
CsrGraph
Enums
- CsrLayout
- Defines how the neighbor list of individual nodes are organized within the CSR target array.
- Direction
- Error
Traits
- Degree
Partition Op - Partition the node set based on the degrees of the nodes.
- Deserialize
Graph Op - Directed
Degrees - Directed
Neighbors - Returns the neighbors of a given node either in outgoing or incoming direction.
- Directed
Neighbors With Values - Returns the neighbors of a given node either in outgoing or incoming direction.
- Edge
Mutation - Allows adding new edges to a graph.
- Edge
Mutation With Values - Allows adding new edges to a graph.
- Edges
- ForEach
Node Parallel ByPartition Op - Call a particular function for each node with its corresponding state in parallel based on a partition.
- ForEach
Node Parallel Op - Call a particular function for each node with its corresponding state in parallel.
- Graph
- A graph is a tuple
(N, E), whereNis a set of nodes andEa set of edges. Each edge connects exactly two nodes. - Idx
- InDegree
Partition Op - Partition the node set based on the in degrees of the nodes.
- Input
Capabilities - Node
Values - A graph that allows storing a value per node.
- OutDegree
Partition Op - Partition the node set based on the out degrees of the nodes.
- Parse
Value - Used by input formats to read node or edge values from bytes.
- Relabel
ByDegree Op - Serialize
Graph Op - ToUndirected
Op - Undirected
Degrees - Undirected
Neighbors - Returns the neighbors of a given node.
- Undirected
Neighbors With Values - Returns the neighbors of a given node.