pub struct DeltaSteppingConfig {
pub start_node: usize,
pub delta: f32,
}Fields
start_node: usizeThe node for which to compute distances to all reachable nodes.
delta: f32Defines the “bucket width”. A bucket maintains nodes with the same tentative distance to the start node.
Implementations