pub struct WccConfig {
pub chunk_size: usize,
pub neighbor_rounds: usize,
pub sampling_size: usize,
}Fields
chunk_size: usizeNumber of nodes to be processed in batch by a single thread.
neighbor_rounds: usizeNumber of relationships of each node to sample during subgraph linking.
sampling_size: usizeNumber of samples to draw from the DSS to find the largest component.
Implementations