Module prelude

Module prelude 

Re-exports

pub use crate::page_rank::*;
pub use crate::sssp::*;
pub use crate::triangle_count::*;
pub use crate::utils::*;
pub use crate::wcc::*;

Modules

binary
edgelist
graph500

Structs

Atomic
A generic atomic wrapper type which allows an object to be safely shared between threads.
BinaryInput
Reads a graph that has been written via crate::graph_ops::SerializeGraphOp.
DirectedALGraph
DirectedCsrGraph
EdgeList
EdgeListInput
Reads a graph from a file that contains an edge per line.
Graph500
Graph500Input
GraphBuilder
A builder to create graphs in a type-safe way.
InputPath
Target
Represents the target of an edge and its associated value.
UndirectedALGraph
UndirectedCsrGraph

Enums

CsrLayout
Defines how the neighbor list of individual nodes are organized within the CSR target array.
Direction
Error

Traits

DegreePartitionOp
Partition the node set based on the degrees of the nodes.
DeserializeGraphOp
DirectedDegrees
DirectedNeighbors
Returns the neighbors of a given node either in outgoing or incoming direction.
DirectedNeighborsWithValues
Returns the neighbors of a given node either in outgoing or incoming direction.
EdgeMutation
Allows adding new edges to a graph.
EdgeMutationWithValues
Allows adding new edges to a graph.
Edges
ForEachNodeParallelByPartitionOp
Call a particular function for each node with its corresponding state in parallel based on a partition.
ForEachNodeParallelOp
Call a particular function for each node with its corresponding state in parallel.
Graph
A graph is a tuple (N, E), where N is a set of nodes and E a set of edges. Each edge connects exactly two nodes.
Idx
InDegreePartitionOp
Partition the node set based on the in degrees of the nodes.
InputCapabilities
NodeValues
A graph that allows storing a value per node.
OutDegreePartitionOp
Partition the node set based on the out degrees of the nodes.
ParseValue
Used by input formats to read node or edge values from bytes.
RelabelByDegreeOp
SerializeGraphOp
ToUndirectedOp
UndirectedDegrees
UndirectedNeighbors
Returns the neighbors of a given node.
UndirectedNeighborsWithValues
Returns the neighbors of a given node.